import { promises as fsp } from "node:fs";
import { fileURLToPath } from "node:url";
import * as nodemailer from "nodemailer";
import handlebars from "handlebars";
import { join, dirname, resolve } from "pathe";
import { createError } from "h3";
import { getModuleOptions } from "./index.js";
const CONFIG_KEY = "arpixEmailSender";
let transporterInstance = null;
let moduleOptions = null;
function getModuleOptionsFromConfig() {
  if (!moduleOptions) {
    moduleOptions = getModuleOptions();
    if (!moduleOptions) {
      throw createError({ statusCode: 500, message: `[nuxt-arpix-email-sender] Configuration key '${CONFIG_KEY}' not found.` });
    }
  }
  return moduleOptions;
}
function createTransporter() {
  const options = getModuleOptionsFromConfig();
  if (options.transport === "smtp") {
    if (!options.smtp) {
      throw createError({ statusCode: 500, message: "[nuxt-arpix-email-sender] Configuration SMTP required but not found." });
    }
    const smtpOptions = {
      ...options.smtp,
      auth: options.smtp.auth ? { ...options.smtp.auth } : void 0
    };
    return nodemailer.createTransport(smtpOptions);
  } else {
    throw createError({ statusCode: 500, message: `[nuxt-arpix-email-sender] Invalid mail transport: ${options.transport}` });
  }
}
function getTransporter() {
  if (!transporterInstance) {
    transporterInstance = createTransporter();
  }
  return transporterInstance;
}
async function renderTemplate(templateName, context) {
  const options = getModuleOptionsFromConfig();
  const templateDir = options.templates?.dir || "server/emails/templates";
  const rootDir = dirname(fileURLToPath(import.meta.url)).split("/.nuxt/")[0];
  const templatePath = resolve(join(rootDir, templateDir, `${templateName}.hbs`));
  try {
    const templateContent = await fsp.readFile(templatePath, "utf-8");
    const compiledTemplate = handlebars.compile(templateContent);
    return compiledTemplate(context);
  } catch (error) {
    console.error(`[nuxt-arpix-email-sender] Error reading or compiling template ${templatePath}:`, error);
    throw createError({
      statusCode: 500,
      message: `Error processing mail template: ${templateName}`,
      cause: error
    });
  }
}
async function send(options) {
  const transporter = getTransporter();
  const config = getModuleOptionsFromConfig();
  const mailOptions = {
    to: options.to,
    subject: options.subject,
    text: options.text,
    html: options.html,
    attachments: options.attachments,
    from: options.from || config.defaultFrom
  };
  if (options.template && options.context) {
    mailOptions.html = await renderTemplate(options.template, options.context);
  } else if (options.template && !options.context) {
    console.warn(`[nuxt-arpix-email-sender] Template '${options.template}' specified but 'context' not provided.`);
  }
  if (!mailOptions.text && !mailOptions.html) {
    throw createError({ statusCode: 400, message: "[nuxt-arpix-email-sender] Mail content required (text, html or template with context)." });
  }
  try {
    const info = await transporter.sendMail(mailOptions);
    console.log(`[nuxt-arpix-email-sender] Mail sent: ${info.messageId}`);
    return info;
  } catch (error) {
    console.error("[nuxt-arpix-email-sender] Error sending mail:", error);
    throw createError({
      statusCode: 500,
      message: "Error sending email.",
      cause: error
    });
  }
}
export function useMailSender() {
  getTransporter();
  return {
    send
  };
}
